@@ -57,6 +57,9 @@ class Text(AlertComponent):
     color: FontColors = FontColors.INFO
     # HTML tag to place text in. e.g. div, p, h1, h2..
     tag: str = "div"
+    
+    def __post_init__(self):
+        self.text = str(self.text)
 
     def html(self) -> d.html_tag:
         tag = getattr(d, self.tag)
@@ -67,10 +70,10 @@ class Text(AlertComponent):
 
     def md(self, slack_format: bool) -> str:
         if slack_format:
-            return self._slack_md()
-        return self._md()
+            return self.slack_md()
+        return self.classic_md()
 
-    def _md(self) -> str:
+    def classic_md(self) -> str:
         if self.size is FontSize.SMALL:
             return self.text
         if self.size is FontSize.MEDIUM:
@@ -78,7 +81,7 @@ class Text(AlertComponent):
         if self.size is FontSize.LARGE:
             return f"# {self.text}"
 
-    def _slack_md(self) -> str:
+    def slack_md(self) -> str:
         if self.color in (FontColors.IMPORTANT, FontColors.ERROR):
             return f"*{self.text}*"
         return self.text
@@ -108,17 +111,17 @@ class KV(AlertComponent):
 
     def md(self, slack_format: bool) -> str:
         if slack_format:
-            return self._slack_md()
+            return self.slack_md()
         return self._md()
 
-    def _md(self) -> str:
+    def classic_md(self) -> str:
         rows = ["|||", "|---:|:---|"]
         for k, v in self.data.items():
             rows.append(f"|**{k}:**|{v}|")
         rows.append("|||")
         return "\n".join(rows)
 
-    def _slack_md(self) -> str:
+    def slack_md(self) -> str:
         return "\n".join([f"*{k}:* {v}" for k, v in self.data.items()])
 
 
@@ -174,10 +177,10 @@ class Table(AlertComponent):
 
     def md(self, slack_format: bool, include_table_rows: bool = True) -> str:
         if slack_format:
-            return self._slack_md(include_table_rows)
+            return self.slack_md(include_table_rows)
         return self._md(include_table_rows)
 
-    def _md(self, include_table_rows: bool) -> str:
+    def classic_md(self, include_table_rows: bool) -> str:
         data = [self.caption.md()]
         if include_table_rows:
             table_rows = [self.header, [":----:" for _ in range(len(self.header))]] + [
@@ -188,8 +191,8 @@ class Table(AlertComponent):
         data.append(self.kv_data.md())
         return "\n\n".join(data).strip()
 
-    def _slack_md(self, include_table_rows: bool) -> str:
-        data = [self.caption._slack_md()]
+    def slack_md(self, include_table_rows: bool) -> str:
+        data = [self.caption.slack_md()]
         if include_table_rows:
             rows = [dict(zip(self.header, self.header))] + self.rows
             # column width is length of longest string + a space of padding on both sides.
@@ -208,5 +211,5 @@ class Table(AlertComponent):
                 ]
             )
             data.append(table)
-        data.append(self.kv_data._slack_md())
+        data.append(self.kv_data.slack_md())
         return "\n\n".join(data).strip()
